
// `victory-vendor/internmap` (CommonJS)
// See upstream license: https://github.com/mbostock/internmap/blob/main/LICENSE
//
// Our CommonJS package relies on transpiled vendor files in `lib-vendor/internmap`
module.exports = require("../lib-vendor/internmap/src/index.js");
